@@ -1,7 +1,7 @@
 /*
  * dvbevents.h
  *
- * Copyright (C) 2003-2006 Christophe Thommeret <hftom@free.fr>
+ * Copyright (C) 2003-2007 Christophe Thommeret <hftom@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,56 +21,24 @@
 #ifndef DVBEVENTS_H
 #define DVBEVENTS_H
 
-#include <sys/poll.h>
+#include <qptrlist.h>
 
-#include <qtimer.h>
-#include <qmutex.h>
-
-#include "dvbsection.h"
-#include "channeldesc.h"
+#include "kaffeinedvbsection.h"
+#include "kaffeinedvbevents.h"
 
 
 
-class EventTsidList
+class DVBevents : public KaffeineDVBsection
 {
-public:
-	EventTsidList( unsigned short t );
-	~EventTsidList();
-	unsigned short tsid;
-	QPtrList<EventDesc> events;
-};
-
-
-
-class EventSourceList
-{
-public:
-	EventSourceList( QString src );
-	~EventSourceList();
-	QString source;
-	QPtrList<EventTsidList> tsidList;
-};
-
-
-
-class DVBevents : public DVBsection
-{
-	Q_OBJECT
 
 public:
 
-	DVBevents( bool *ok, int anum, int tnum, const QString &charset );
+	DVBevents( QString devType, int anum, int tnum, const QString &charset, EventTable *table );
 	~DVBevents();
-	bool go( QString src, bool all=false );
+	bool go( QString src, int freqKHz, bool all=false );
 	void stop();
-	void doClean( bool b );
-	void dumpEvents();
 
-	QPtrList<EventSourceList> srcList;
-	EventSourceList *currentSrcList;
-	QMutex mutex;
-
-protected:
+private:
 
 	virtual void run();
 	bool tableEIT( unsigned char* buffer );
@@ -78,25 +46,14 @@ protected:
 	bool extEventDesc( unsigned char *buf, EventDesc *desc );
 	bool safeLen( unsigned char* buf );
 
-	bool clean;
-	QTimer cleanTimer;
-
-private slots:
-
-	void setClean();
-
-private:
-
 	unsigned char secbuf[4096];
 	int readSize;
-	bool demuxOpened;
-	struct pollfd pf[1];
-	QString source;
 
-signals:
-
-	void newEvent( EventDesc* );
+	EventTable *events;
+	EventSource *currentSrc;
 
+	QPtrList<KaffeineEpgPlugin> plugs;
+	QStringList plugNames;
 };
 
 #endif /* DVBEVENTS_H */
